Documentation
¶
Overview ¶
*
- Florence
- Copyright (C) 2024 hannjosh *
- This program is free software: you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation, either version 3 of the License, or
- (at your option) any later version. *
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- GNU General Public License for more details. *
- You should have received a copy of the GNU General Public License
- along with this program. If not, see <https://www.gnu.org/licenses/>.
*
- Florence
- Copyright (C) 2024 hannjosh *
- This program is free software: you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation, either version 3 of the License, or
- (at your option) any later version. *
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- GNU General Public License for more details. *
- You should have received a copy of the GNU General Public License
- along with this program. If not, see <https://www.gnu.org/licenses/>.
Index ¶
Constants ¶
const ApiVersion string = "v61.0"
* Version of the Salesforce REST API to use. * @since 1.0.0
Variables ¶
var MyDomain string
* My Domain * The subdomain of the Salesforce org. * @since 1.0.0
var OAuth2AccessToken string
* OAuth 2.0 access token used to authorise the client. * The Salesforce REST API supports the Bearer authentication type. * @since 1.0.0
Functions ¶
func GetOAuth2AccessToken ¶
* GetAuthorizationToken * Obtains an OAuth 2.0 access token to authorise calls to the Salesforce REST API. * @since 1.0.0
Types ¶
type KitItem__c ¶ added in v1.0.2
Click to show internal directories.
Click to hide internal directories.